============
Installation
============


Requirements
------------

 * pymadx is developed exclusively for Python 2.7.
 * Matplotlib
 * Numpy

Installation
------------

To install pymadx, simply run ``make install`` from the root pymadx
directory.::

  cd /my/path/to/repositories/
  git clone http://bitbucket.org/jairhul/pymadx
  cd pymadx
  make install

Alternatively, run ``make develop`` from the same directory to ensure
that any local changes are picked up.
